COMPMID-481: Add thread info parameter

Change-Id: Iebb50a88d017445b6b37a86563ebd4abd86c5cf5
Reviewed-on: http://mpd-gerrit.cambridge.arm.com/86788
Tested-by: Kaizen <jeremy.johnson+kaizengerrit@arm.com>
Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
diff --git a/arm_compute/core/NEON/kernels/NEHistogramKernel.h b/arm_compute/core/NEON/kernels/NEHistogramKernel.h
index 2c0f34b..75d00e9 100644
--- a/arm_compute/core/NEON/kernels/NEHistogramKernel.h
+++ b/arm_compute/core/NEON/kernels/NEHistogramKernel.h
@@ -77,7 +77,7 @@
     void configure(const IImage *input, IDistribution1D *output);
 
     // Inherited methods overridden:
-    void run(const Window &window) override;
+    void run(const Window &window, const ThreadInfo &info) override;
 
 private:
     /** Function to merge multiple partial histograms.
@@ -95,15 +95,17 @@
     void merge_min(uint8_t *global_min, const uint8_t &local_min);
     /** Function to perform histogram on the given window
       *
      *  @param[in] win Region on which to execute the kernel
      */
-    void histogram_U8(Window win);
+    void histogram_U8(Window win, const ThreadInfo &info);
     /** Function to perform histogram on the given window where histogram is
      *         of fixed size 256 without ranges and offsets.
      *
      *  @param[in] win Region on which to execute the kernel
      */
-    void histogram_fixed_U8(Window win);
+    void histogram_fixed_U8(Window win, const ThreadInfo &info);
     /** Pre-calculate the pixel windowing for every possible pixel
      *
      * Calculate (V - offset) * numBins / range where V is every possible pixel value.
@@ -115,7 +117,7 @@
      *
      * @param[in] window Region on which to execute the kernel.
      */
-    using HistogramFunctionPtr = void (NEHistogramKernel::*)(Window window);
+    using HistogramFunctionPtr = void (NEHistogramKernel::*)(Window window, const ThreadInfo &info);
 
     HistogramFunctionPtr          _func; ///< Histogram function to use for the particular image types passed to configure()
     const IImage                 *_input;
@@ -95,15 +95,17 @@
     /** Function to perform histogram on the given window
       *
-     *  @param[in] win Region on which to execute the kernel
+     *  @param[in] win  Region on which to execute the kernel
+     *  @param[in] info Info about the executing thread
      */
@@ -95,15 +95,17 @@
      *         of fixed size 256 without ranges and offsets.
      *
-     *  @param[in] win Region on which to execute the kernel
+     *  @param[in] win  Region on which to execute the kernel
+     *  @param[in] info Info about the executing thread
      */